@@ -1,7 +1,6 @@
 package App::skryf::Command::newpage;
 
-use strict;
-use warnings;
+use strictures 1;
 use v5.16;
 use FindBin '$Bin';
 use Mojo::Base 'Mojolicious::Command';
@@ -9,6 +8,8 @@ use Path::Tiny;
 use DateTime;
 use App::skryf::Util;
 
+our $VERSION = '0.006'; # VERSION
+
 has description => "Create a new static page.\n";
 has usage => <<"EOF";
 Usage: $0 newpage page-name
