@@ -1,7 +1,6 @@
 package App::skryf::Command::repost;
 
-use strict;
-use warnings;
+use strictures 1;
 use v5.16;
 use FindBin '$Bin';
 use Mojo::Base 'Mojolicious::Command';
@@ -10,7 +9,7 @@ use DateTime;
 
 use App::skryf::Util;
 
-# VERSION
+our $VERSION = '0.006'; # VERSION
 
 has description => "Edit pending posts.\n";
 has datetime => sub {
